---
title: 네이버페이 채널설정방법
category: 결제서비스 (채널설정 및 이용안내) > 채널설정 > 채널설정
seo:
  title: 네이버페이 채널설정방법
  description: >-
    결제형 네이버페이 결제 연동을 위한 채널 설정 방법을 안내드립니다. '테스트 연동, 실 연동' 순으로 이뤄지며, 결제대행사와 연동방식별로
    설정하는 정보는 상이할 수 있습니다.
  keywords:
    - 네이버페이
    - 결제형
    - 주문형
    - 일반결제
    - 정기결제
    - 결제연동
    - 채널설정방법
    - 채널추가
tags:
  - 네이버페이
  - 결제
  - 채널설정방법
pgCompanies:
  - 네이버페이(결제형)
searchTags:
  - 네이버페이실연동
  - 네이버페이테스트
  - 네이버페이결제형테스트
  - 네이버페이주문형테스트
  - 네이버페이 결제형
  - 네이버페이 주문형
  - 파트너ID
  - 네이버페이연동
  - 네이버페이설정
  - 네이버페이결제형
  - 네이버페이
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="결제 연동을 위한 채널 설정 방법을 안내해 드립니다.
결제 연동을 위해서 채널설정은 필수이며 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
또한 채널 설정 없이 결제 연동을 하실 경우 정상적인 호출이 불가하며, 오류가 발생됩니다." />

<Highlight url="#7_네이버페이-주문형" text="네이버페이 주문형 설정 바로가기 ↓" />

## <Highlight text="네이버페이 결제형" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 바로가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout title="참고사항" icon="💡" content="1. 네이버페이는 범용적인 key가 별도 발급되지 않아 **고객사별로 가입신청 후 테스트용 key를 발급받아 이용해주셔야 합니다.**
2. **결제형 서비스는 가입신청시 입점기준인 [최소 1개월 이상 매출발생] , [일반PG가입여부] 을 먼저 확인하므로, 기준을 확인하신 후 접수부탁드립니다.**
3. 일반결제와 정기결제 설정은 똑같으며 하나의 채널로 설정하신 후 이용해주시기 바랍니다." />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 네이버페이
  - 결제모듈 : 네이버페이 결제형

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (파트너 ID) : 네이버페이 1차 승인 이후 메일로 발급되는 페이센터(Shop)아이디
  \
  ex) np\_\*\*\*\*\*\*\*\* 로 설정 (네이버페이 가입신청 이후 메일로 발급 및 안내됨)
- ClientID : 네이버페이 가입신청 이후 1차승인시 메일로 발급 및 안내되는 Client ID
- Client Secret : 네이버페이 가입신청 이후 1차승인시 메일로 발급 및 안내되는 Client Secret
- Chain ID : 포트원 정산서비스 및 v2모듈 사용시 설정값
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)

<Callout content="네이버페이의 검수 과정이 모두 완료된 이후 실 운영환경용 상점정보로 설정해주셔야 합니다. " title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : 네이버페이
  - 결제모듈 : 네이버페이 결제형

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (파트너 ID) : 네이버페이 1차 승인 이후 메일로 발급되는 페이센터(Shop)아이디
  \
  ex) np\_\*\*\*\*\*\*\*\* 로 설정 (네이버페이 가입신청 이후 메일로 발급 및 안내됨)
- ClientID : 네이버페이 가입신청 이후 1차승인시 메일로 발급 및 안내되는 Client ID
- Client Secret : 네이버페이 가입신청 이후 1차승인시 메일로 발급 및 안내되는 Client Secret
- Chain ID : 포트원 정산서비스 및 v2모듈 사용시 설정값
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

<Callout title="V2 네이버페이(결제형) 개발가이드 보러가기↗" />

<Callout title="V1 네이버페이(결제형) 개발가이드 보러가기↗" />

## <Highlight text="네이버페이 주문형" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 바로가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout title="참고사항" icon="💡" content="1. 네이버페이는 범용적인 key가 별도 발급되지 않아 고객사별로 가입신청 후 테스트용 key를 발급받아 이용해주셔야 합니다.
2. 주문형 서비스는 비실물 서비스(컨텐츠) 서비스 이용은 불가한 점 참고부탁드립니다.
(결제형만 지원 가능)" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 네이버페이
  - 결제모듈 : 네이버페이 주문형

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (가맹점 ID) : 네이버페이 1차 승인 이후 메일로 발급되는 페이센터(Shop)아이디
  \
  ex) np\_\*\*\*\*\*\*\*\* 로 설정 (네이버페이 가입신청 이후 메일로 발급 및 안내됨)
- certiKey : 네이버페이 가입신청 이후 1차승인시 메일로 발급 및 안내되는 certiKey
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)

<Callout content="네이버페이의 검수 과정이 모두 완료된 이후 실 운영환경용 상점정보로 설정해주셔야 합니다. " title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 네이버페이
  - 결제모듈 : 네이버페이 주문형

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (가맹점 ID) : 네이버페이 1차 승인 이후 메일로 발급되는 페이센터(Shop)아이디
  \
  ex) np\_\*\*\*\*\*\*\*\* 로 설정 (네이버페이 가입신청 이후 메일로 발급 및 안내됨)
- certiKey : 네이버페이 가입신청 이후 1차승인시 메일로 발급 및 안내되는 certiKey
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

<Callout title="네이버페이(주문형) 개발가이드 보러가기↗" />
